# MLable

NN model drafts:

- GPM: stateless password manager, with LLM generation
- GPT: learning projects on the transformer arch
- makemore: learning project similar to makemore
- sold: solidity (de)compiler
- tokun: neural tokenizer, covers the whole Unicode space

## TODO

See [TODO](TODO.md).

## License

Licensed under the [aGPLv3](LICENSE.md).

[code-micrograd]: https://github.com/karpathy/micrograd
[video-karpathy]: https://www.youtube.com/@AndrejKarpathy/videos
